=========
Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog`_, and this project adheres to `Semantic Versioning`_.

`Unreleased`_
-------------

`0.5.0`_ - 2022-01-02
---------------------

Added
^^^^^
* Added python310 support
* Added a changelog

Changed
^^^^^^^
* Change gatherer url scheme to https

Removed
^^^^^^^
* Dropped python36 support

`0.4.0`_ - 2020-05-18
---------------------

Changed
^^^^^^^
* Updated requirements

`0.3.0`_ - 2018-12-19
---------------------

Removed
^^^^^^^
* Removed the following classes, as they don't offer extra functionality:

  * Card
  * CardParser

`0.2.0`_ - 2018-12-19
---------------------

Changed
^^^^^^^
* Changed the package name to pygatherer

`0.1.0`_ - 2018-10-06
---------------------

Added
^^^^^
* Added more trove classifiers to the package

`0.0.3`_ - 2018-10-06
---------------------

Added
^^^^^
* Added more information to the package

`0.0.2`_ - 2018-09-02
---------------------

Changed
^^^^^^^
* Made the requirements less strict

`0.0.1`_ - 2018-08-27
---------------------

Added
^^^^^
* Added a parser for a single multiverse id


.. _`unreleased`: https://github.com/spapanik/pygatherer/compare/0.5.0...master
.. _`0.5.0`: https://github.com/spapanik/pygatherer/compare/0.4.0...v0.5.0
.. _`0.4.0`: https://github.com/spapanik/pygatherer/compare/0.3.0...v0.4.0
.. _`0.3.0`: https://github.com/spapanik/pygatherer/compare/0.2.0...v0.3.0
.. _`0.2.0`: https://github.com/spapanik/pygatherer/compare/0.1.0...v0.2.0
.. _`0.1.0`: https://github.com/spapanik/pygatherer/compare/0.0.3...v0.1.0
.. _`0.0.3`: https://github.com/spapanik/pygatherer/compare/0.0.2...v0.0.3
.. _`0.0.2`: https://github.com/spapanik/pygatherer/compare/v0.0.1...v0.0.2
.. _`0.0.1`: https://github.com/spapanik/pygatherer/releases/tag/v0.0.1

.. _`Keep a Changelog`: https://keepachangelog.com/en/1.0.0/
.. _`Semantic Versioning`: https://semver.org/spec/v2.0.0.html
